BPReg: Bayesian penalized regressions for non-stationary Gaussian...

View source: R/BPReg.R

BPRegR Documentation

Bayesian penalized regressions for non-stationary Gaussian linear mixed effects model.

Description

Bayesian penalized regressions for non-stationary Gaussian linear mixed effects model.

Usage

BPReg(
  y,
  x,
  time,
  id,
  n.samples,
  r.init,
  delta.init,
  method = c("BEN", "BAL", "BR", "BL")
)

Arguments

y

A vector for the response variable.

x

A data frame that includes scaled covariates whose coefficients will be penalized.

time

A vector for the time variable (e.g. age)

id

A vector for the individuals id.

n.samples

MCMC sample size.

r.init

value assumed for r, a paramater of the Gamma prior (see Gecili et al.2020).

delta.init

value assumed for delta, a paramater of the Gamma prior (see Gecili et al.2020)

method

It allows for BEN (Bayesian elastic-net), BAL (Bayesian adaptive lasso), BL (Bayesian lasso), and BR (Bayesian ridge).

Value

Returns posterior estimates and credible intervals.

Examples

BPReg(y,x,time,id,n.samples =25000,r.init = 1,delta.init = 1,method = "BR")

egecili54/BPReg documentation built on Jan. 4, 2025, 5:01 p.m.