MCMCplot: MCMCplot

MCMCplotR Documentation

MCMCplot

Description

Returns caterpillar plot for selected parameters with credible intervals. Points represent posterior medians. Thick lines represent 50 percent credible intervals while thin lines represent 95 percent credible intervals. ref_ovl = TRUE makes circle empty.

Usage

MCMCplot(M, ref_ovl = TRUE)

Arguments

M

Final MCMC output after burnin.

Value

Returns caterpillar plot for selected parameters with credible intervals.

Examples

MCMCplot(M,params=colnames(M),ref_ovl = TRUE)

egecili54/BPReg documentation built on Jan. 4, 2025, 5:01 p.m.