posterior_summary: Returns posterior summary

posterior_summaryR Documentation

Returns posterior summary

Description

Summarizes posterior samples based on point estimates (mean or median), estimation errors (SD or MAD) and quantiles If FALSE (the default) the mean is used as the measure of central tendency and the standard deviation as the measure of variability. If TRUE, the median and the median absolute deviation (MAD) are applied instead.

Usage

posterior_summary(M)

Arguments

M

Final MCMC output after burnin.

Value

Returns posterior summary.

Examples

posterior_summary(M, probs = c(0.025, 0.975),robust =FALSE)

egecili54/BPReg documentation built on Jan. 4, 2025, 5:01 p.m.