| BPReg | R Documentation |
Bayesian penalized regressions for non-stationary Gaussian linear mixed effects model.
BPReg(
y,
x,
time,
id,
n.samples,
r.init,
delta.init,
method = c("BEN", "BAL", "BR", "BL")
)
y |
A vector for the response variable. |
x |
A data frame that includes scaled covariates whose coefficients will be penalized. |
time |
A vector for the time variable (e.g. age) |
id |
A vector for the individuals id. |
n.samples |
MCMC sample size. |
r.init |
value assumed for r, a paramater of the Gamma prior (see Gecili et al.2020). |
delta.init |
value assumed for delta, a paramater of the Gamma prior (see Gecili et al.2020) |
method |
It allows for BEN (Bayesian elastic-net), BAL (Bayesian adaptive lasso), BL (Bayesian lasso), and BR (Bayesian ridge). |
Returns posterior estimates and credible intervals.
BPReg(y,x,time,id,n.samples =25000,r.init = 1,delta.init = 1,method = "BR")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.