| MCMCplot | R Documentation |
Returns caterpillar plot for selected parameters with credible intervals. Points represent posterior medians. Thick lines represent 50 percent credible intervals while thin lines represent 95 percent credible intervals. ref_ovl = TRUE makes circle empty.
MCMCplot(M, ref_ovl = TRUE)
M |
Final MCMC output after burnin. |
Returns caterpillar plot for selected parameters with credible intervals.
MCMCplot(M,params=colnames(M),ref_ovl = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.