| posterior_summary | R Documentation |
Summarizes posterior samples based on point estimates (mean or median), estimation errors (SD or MAD) and quantiles If FALSE (the default) the mean is used as the measure of central tendency and the standard deviation as the measure of variability. If TRUE, the median and the median absolute deviation (MAD) are applied instead.
posterior_summary(M)
M |
Final MCMC output after burnin. |
Returns posterior summary.
posterior_summary(M, probs = c(0.025, 0.975),robust =FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.